from .ColorKit import BgColor

class bgcolor:
    def default():
        print(BgColor.default)
    def black():
        print(BgColor.black)
    def red():
        print(BgColor.red)
    def green():
        print(BgColor.green)
    def yellow():
        print(BgColor.yellow)
    def blue():
        print(BgColor.blue)
    def purple():
        print(BgColor.purple)
    def cyan():
        print(BgColor.cyan)
    def lightgrey():
        print(BgColor.lightgrey)
    def darkgrey():
        print(BgColor.darkgrey)
    def lightred():
        print(BgColor.lightred)
    def lightgreen():
        print(BgColor.lightgreen)
    def lightyellow():
        print(BgColor.lightyellow)
    def lightblue():
        print(BgColor.lightblue)
    def lightmagenta():
        print(BgColor.lightmagenta)
    def lightcyan():
        print(BgColor.lightcyan)
    def white():
        print(BgColor.white)
    def custom(color=''):
        print(color)

